using System;
using System.IO;
using System.Data;
using System.Configuration;
using System.Xml;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;

/// <summary>
/// Vlastni SiteMapProvider, ktery prochazi vsechny *.html soubory
/// v aktualnim adresari a vytvari na ne odkazy
/// </summary>
public class FileSiteMap : StaticSiteMapProvider
{
	// korenova node nasi site mapy
	SiteMapNode root=null;

	/// <summary>
	/// Pomocna fce: zjistuje z xhtml souboru jeho titulek
	/// </summary>
	private string GetFileTitle(string file)
	{
		// pokud je soubor validni, muzeme zjistit titulek pomoci XML
		XmlDocument doc=new XmlDocument();
		try
		{
			doc.Load(file);
			XmlNode title=doc.SelectSingleNode("html/head/title");
			if (title!=null)
				return title.InnerText;
			else
				return "Untitled";
		}
		catch { return "Untitled"; }
	}


	/// <summary>
	/// Funkce, ktera vytvori mapu stranky
	/// </summary>
	/// <returns>Vraci korenovou node</returns>
	public override SiteMapNode BuildSiteMap()
	{
		if (root!=null) return root;

		// korenova node je stranka default.aspx
		root=new SiteMapNode(this, "default", "default.aspx", "Hlavn strnka");

		// projde vsechny soubory ...
		string[] files=Directory.GetFiles(HttpContext.Current.Server.MapPath(""), "*.html");
		foreach (string file in files)
		{
			// .. zjisti jmeno souboru ...
			string name=Path.GetFileName(file); 
			// .. a prida je do jako potomky root node
			AddNode(new SiteMapNode(this, name, name, GetFileTitle(file)), root);
		}

		return root;
	}

	/// <summary>
	/// Vraci korenovou node mapy 
	/// (pokud jeste neni vytvorena vytvari mapu stranek)
	/// </summary>
	protected override SiteMapNode GetRootNodeCore()
	{
		if (root==null) BuildSiteMap();
		return root;
	}
}
